@@ -324,8 +324,8 @@ print.prior <- function(x, short_name = FALSE, parameter_names = FALSE, plot = F
 }
 .print.prior.spike_and_slab <- function(x, short_name, parameter_names, plot, digits_estimates, silent){
 
-  variable  <- print(x[["variable"]],  short_name, parameter_names, plot, digits_estimates, silent = TRUE)
-  inclusion <- print(x[["inclusion"]], short_name, parameter_names, plot, digits_estimates, silent = TRUE)
+  variable  <- print(.get_spike_and_slab_variable(x),  short_name, parameter_names, plot, digits_estimates, silent = TRUE)
+  inclusion <- print(.get_spike_and_slab_inclusion(x), short_name, parameter_names, plot, digits_estimates, silent = TRUE)
 
   ### combine the results together
   if(!plot){
