@@ -1,6 +1,6 @@
 .onLoad <- function(libname, pkgname){
 
   # load runjags
-  requireNamespace("rjags")
-  requireNamespace("runjags")
+  # requireNamespace("rjags")
+  # requireNamespace("runjags")
 }
